package com.fs.fastGpt.service;


import com.fs.common.core.domain.R;
import com.fs.fastGpt.domain.FastGptDataset;

import java.util.List;

/**
 * 知识库列Service接口
 * 
 * @author fs
 * @date 2024-09-30
 */
public interface IFastGptDatasetService 
{
    /**
     * 查询知识库列
     * 
     * @param datasetId 知识库列主键
     * @return 知识库列
     */
    public FastGptDataset selectFastGptDatasetByDatasetId(String datasetId);

    /**
     * 查询知识库列列表
     * 
     * @param fastGptDataset 知识库列
     * @return 知识库列集合
     */
    public List<FastGptDataset> selectFastGptDatasetList(FastGptDataset fastGptDataset);

    public R syncDataset(Long companyId);
    /**
     * 新增知识库列
     * 
     * @param fastGptDataset 知识库列
     * @return 结果
     */
    public R insertFastGptDataset(FastGptDataset fastGptDataset);

    /**
     * 修改知识库列
     * 
     * @param fastGptDataset 知识库列
     * @return 结果
     */
    public int updateFastGptDataset(FastGptDataset fastGptDataset);

    /**
     * 批量删除知识库列
     * 
     * @param datasetIds 需要删除的知识库列主键集合
     * @return 结果
     */
    public R deleteFastGptDatasetByDatasetIds(String[] datasetIds,Long companyId);

    /**
     * 删除知识库列信息
     * 
     * @param datasetId 知识库列主键
     * @return 结果
     */
    public int deleteFastGptDatasetByDatasetId(String datasetId);
}
